@@ -1,5 +1,7 @@
 from __future__ import absolute_import
 
+from cStringIO import StringIO
+
 from mock import Mock
 
 from thriftworker.tests.utils import TestCase, CustomAppMixin
@@ -23,6 +25,6 @@ class TestServices(CustomAppMixin, TestCase):
         self.services.register(self.service_name, self.processor)
         process_mock = self.processor.process = Mock(return_value=None)
         process = self.services.create_processor(self.service_name)
-        self.assertEqual('', process(b'xxxx'))
+        self.assertEqual((None, ''), process(StringIO(b'xxxx')))
         self.assertTrue(process_mock.called)
         self.assertEqual(1, process_mock.call_count)
